@@ -1,4 +1,5 @@
 from flask import Flask
+
 app = Flask(__name__)
 import omc
 import sys
@@ -8,6 +9,8 @@ import omc
 import traceback
 import json
 from flask import jsonify
+
+
 @app.route("/zz/<path:path>")
 def cmd(path):
     FORMAT = "[%(filename)s:%(lineno)s - %(funcName)s ] %(message)s"
@@ -15,22 +18,23 @@ def cmd(path):
     logger = logging.getLogger(__name__)
     argv = path.split('/')
     resource_type = argv[0]
-    print('########################## resource type:' + resource_type)
+    print('################## resource type:' + resource_type + '##################')
     try:
-        mod = __import__(".".join(['omc', 'resources', resource_type, resource_type]), fromlist=[resource_type.capitalize()])
+        mod = __import__(".".join(['omc', 'resources', resource_type, resource_type]),
+                         fromlist=[resource_type.capitalize()])
         clazz = getattr(mod, resource_type.capitalize())
         context = {
             'all': ['web', *argv],
             'index': 1
         }
         data = clazz(context)._exec()
-    
+
         response = app.response_class(
-            response = json.dumps(data),
+            response=json.dumps(data),
             mimetype='application/json'
         )
         return response
 
     except Exception as inst:
         traceback.print_exc()
-        logger.error(inst)
\ No newline at end of file
+        logger.error(inst)
